'use strict';

const path = require('node:path');

class Logger {
  static ErrorAndExit(...args) {
    Logger.Error(...args);
    process.exit(1);
  }

  static ErrorAndExitNoException(...args) {
    Logger.ErrorNoException(...args);
    process.exit(1);
  }


  static ErrorAndThrow(...args) {
    Logger.Error(...args);
    throw new Error();
  }

  static ErrorNoException(...args) {
    console.log();

    const size = args?.length ?? 0;
    for(let idx = 0; idx < size; idx++) {
      args[idx] = Logger.Red(Logger.Bold(args[idx]));
    }
    console.error(Logger.Red(Logger.Bold('JsView Error:')), ...args);
  }

  static Error(...args) {
    console.log();

    const size = args?.length ?? 0;
    for(let idx = 0; idx < size; idx++) {
      args[idx] = Logger.Red(Logger.Bold(args[idx]));
    }
    console.error(Logger.Red(Logger.Bold('JsView Error:')), ...args, '\n', new Error());
  }

  static Warn(...args) {
    console.log();

    const size = args?.length ?? 0;
    for(let idx = 0; idx < size; idx++) {
      args[idx] = Logger.Yellow(Logger.Bold(args[idx]));
    }
    console.warn(Logger.Yellow(Logger.Bold('JsView Warning:')), ...args);
  }

  static Info(...args) {
    console.info(Logger.Green('JsView Info:'), ...args);
  }

  static Debug(...args) {
    const stack = new Error().stack;
    const caller = stack.split('\n')[2].trim().split(' ')[1] + '()';
    console.debug('JsView Debug:', caller, ...args);
  }

  static GetFileTag(filePath) {
    const dirName = path.dirname(filePath)
    const fileName = path.basename(filePath)
    const fileTag = Logger.Blue('[/.../' + path.basename(dirName) + '/' + fileName + ']');
    return fileTag;
  }

  static Red(log) {
    return '\x1b[31m' + log + '\x1b[39m';
  }

  static Green(log) {
    return '\x1b[32m' + log + '\x1b[39m';
  }

  static Yellow(log) {
    return '\x1b[33m' + log + '\x1b[39m';
  }

  static Blue(log) {
    return '\x1b[34m' + log + '\x1b[39m';
  }

  static Bold(log) {
    return '\x1B[1m' + log + '\x1B[22m';
  }
}

module.exports = {
  Logger
}